==> rdfjs__parser-jsonld-2.1.0.tgz: rdfjs__parser-jsonld/README.md <==
# Installation
> `npm install --save @types/rdfjs__parser-jsonld`

# Summary
This package contains type definitions for @rdfjs/parser-jsonld (https://github.com/rdfjs-base/parser-jsonld).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/rdfjs__parser-jsonld.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/rdfjs__parser-jsonld/index.d.ts)
````ts
// Type definitions for @rdfjs/parser-jsonld 2.1
// Project: https://github.com/rdfjs-base/parser-jsonld
// Definitions by: Chris Wilkinson <https://github.com/thewilkybarkid>
//                 tpluscode <https://github.com/tpluscode>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped

import { Context } from 'jsonld/jsonld-spec';
import { DataFactory, Sink, Stream, BaseQuad, Quad } from 'rdf-js';
import { EventEmitter } from 'events';

export interface ParserOptions {
    baseIRI?: string | undefined;
    context?: Context | undefined;
    factory?: DataFactory | undefined;
}

export default class Parser<Q extends BaseQuad = Quad> implements Sink<EventEmitter, Stream<Q>> {
    constructor(options?: ParserOptions);

    import(stream: EventEmitter, options?: ParserOptions): Stream<Q>;
}

````

### Additional Details
 * Last updated: Mon, 27 Mar 2023 18:33:57 GMT
 * Dependencies: [@types/jsonld](https://npmjs.com/package/@types/jsonld), [@types/rdf-js](https://npmjs.com/package/@types/rdf-js)
 * Global values: none

# Credits
These definitions were written by [Chris Wilkinson](https://github.com/thewilkybarkid), and [tpluscode](https://github.com/tpluscode).

==> rdfjs__parser-jsonld-2.1.1.tgz: rdfjs__parser-jsonld/README.md <==
# Installation
> `npm install --save @types/rdfjs__parser-jsonld`

# Summary
This package contains type definitions for @rdfjs/parser-jsonld (https://github.com/rdfjs-base/parser-jsonld).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/rdfjs__parser-jsonld.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/rdfjs__parser-jsonld/index.d.ts)
````ts
// Type definitions for @rdfjs/parser-jsonld 2.1
// Project: https://github.com/rdfjs-base/parser-jsonld
// Definitions by: Chris Wilkinson <https://github.com/thewilkybarkid>
//                 tpluscode <https://github.com/tpluscode>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped

import { Context } from 'jsonld/jsonld-spec.js';
import { DataFactory, Sink, Stream, BaseQuad, Quad } from 'rdf-js';
import { EventEmitter } from 'events';

export interface ParserOptions {
    baseIRI?: string | undefined;
    context?: Context | undefined;
    factory?: DataFactory | undefined;
}

export default class Parser<Q extends BaseQuad = Quad> implements Sink<EventEmitter, Stream<Q>> {
    constructor(options?: ParserOptions);

    import(stream: EventEmitter, options?: ParserOptions): Stream<Q>;
}

````

### Additional Details
 * Last updated: Fri, 28 Jul 2023 19:02:49 GMT
 * Dependencies: [@types/jsonld](https://npmjs.com/package/@types/jsonld), [@types/rdf-js](https://npmjs.com/package/@types/rdf-js)
 * Global values: none

# Credits
These definitions were written by [Chris Wilkinson](https://github.com/thewilkybarkid), and [tpluscode](https://github.com/tpluscode).
